/** Copyright (C) 2017 by Bundesanstalt für Gewässerkunde
 * Software engineering by
 *  Björnsen Beratende Ingenieure GmbH
 *  Dr. Schumacher Ingenieurbüro für Wasser und Umwelt
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */
package org.dive4elements.river.artifacts.bundu.bezugswst;

import java.util.List;

import org.dive4elements.artifactdatabase.state.Facet;
import org.dive4elements.river.artifacts.common.AbstractCalculationExportableResult;
import org.dive4elements.river.artifacts.model.CalculationResult;
import org.dive4elements.river.artifacts.model.WQKms;
import org.dive4elements.river.artifacts.model.fixings.FixWaterlevelFacet;
import org.dive4elements.river.artifacts.states.DefaultState.ComputeType;

public class BezugswstFixationFacet extends FixWaterlevelFacet {

    private static final long serialVersionUID = 1L;

    public BezugswstFixationFacet() {
    }

    public BezugswstFixationFacet(final int index, final String name, final String description, final ComputeType type, final String hash,
            final String stateID) {
        super(index, name, description, type, hash, stateID);
    }

    @Override
    protected WQKms[] getWQKms(final CalculationResult res) {

        final BezugswstCalculationResults results = (BezugswstCalculationResults) res.getData();

        final List<AbstractCalculationExportableResult> resultList = results.getResults();

        if (!resultList.isEmpty())
            return new WQKms[] { ((BezugswstMainCalculationResult) resultList.get(0)).getWQKms() };
        return null;
    }

    /** Copy deeply. */
    @Override
    public Facet deepCopy() {
        final BezugswstFixationFacet copy = new BezugswstFixationFacet();
        copy.set(this);
        copy.type = this.type;
        copy.hash = this.hash;
        copy.stateId = this.stateId;
        return copy;
    }
}
